@@ -286,19 +286,16 @@ MIDI_TO_FREQ = {
     m: NOTE_TO_FREQ[n] for n, m in NOTE_TO_MIDI.items() if n in NOTE_TO_FREQ
 }
 
+
 CHORDS = {
-    "MAJ": [0, 4, 7],
     "MAJ_NO5": [0, 4],
     "POWER": [0, 7],
     "SUS": [0, 5, 7],
     "SUS2": [0, 2, 7],
-    "7SUS": [0, 5, 7],
-    "7SUS2": [0, 2, 7],
+    "7SUS": [0, 5, 11],
+    "7SUS2": [0, 2, 11],
     "MAJ6": [0, 4, 7, 9],
     "MAJ6_NO5": [0, 4, 9],
-    "MAJ6_9": [0, 4, 9, 14],
-    "MAJ9": [0, 4, 7, 14],
-    "MIN": [0, 3, 7],
     "MIN_NO5": [0, 3],
     "MIN6": [0, 3, 7, 9],
     "MIN6_NO5": [0, 3, 9],
@@ -309,8 +306,36 @@ CHORDS = {
     "MAJ7_NO5": [0, 4, 11],
     "MIN7": [0, 3, 7, 10],
     "MIN7_NO5": [0, 3, 10],
-    "MAJ9": [0, 4, 7, 14],
-    "MAJ9_NO5": [0, 4, 14],
+    "MAJ": [0, 4, 7],
+    "MAJ9": [0, 4, 7, 11, 21],
+    "MAJ13": [0, 4, 7, 11, 21],
+    "ADD6": [0, 4, 7, 9],
+    "MAJ69": [0, 4, 7, 9, 14],
+    "LYD": [0, 4, 7, 11, 15, 21],
+    "MAJ7_FLAT6": [0, 4, 7, 11, 20],
+    "DOM7": [0, 4, 7, 10],
+    "DOM9": [0, 4, 7, 10, 21],
+    "DOM13": [0, 4, 7, 10, 19],
+    "LYD_DOM7": [0, 4, 7, 10, 15],
+    "DOM_FLAT14": [0, 4, 7, 10, 20, 4, 9],
+    "DOM_SHARP14": [0, 4, 7, 10, 17, 14, 19],
+    "ALT7": [0, 4, 10, 20, 8],
+    "SUS4": [0, 5, 7],
+    "SUS2": [0, 2, 7],
+    "7SUS4": [0, 4, 7, 10],
+    "11": [0, 7, 10, 21, 16],
+    "11SPEC": [0, 4, 7, 10, 21, 16],
+    "PHRYG": [0, 5, 7, 20],
+    "MAJ": [0, 4, 7],
+    "MIN": [0, 3, 7],
+    "MINAJ7": [0, 3, 7, 11, 14, 19],
+    "MINAJ7_13": [0, 3, 7, 11, 14, 18],
+    "MIN9": [0, 3, 7, 10, 14],
+    "MIN11": [0, 3, 7, 10, 14, 16],
+    "MIN13": [0, 3, 7, 10, 14, 16, 19],
+    "DIM": [0, 3, 6],
+    "DIM7": [0, 3, 6, 9],
+    "HALF_DIM": [0, 3, 6, 9, 13],
 }
 
 SCALES = {
